@@ -29,6 +29,7 @@
 #'                        \item \strong{\code{"raw"}}: For debugging, produces probabilities of all alternatives and individual model components at the level of an observation, at the level of individual draws.
 #'                        \item \strong{\code{"report"}}: Prepares output summarising model and choiceset structure.
 #'                        \item \strong{\code{"shares_LL"}}: Produces overall model likelihood with constants only.
+#'                        \item \strong{\code{"utilities"}}: Returns utilities at provided parameter values.
 #'                        \item \strong{\code{"validate"}}: Validates model specification, produces likelihood of the full model, at the level of individual decision-makers, after averaging across draws.
 #'                        \item \strong{\code{"zero_LL"}}: Produces overall model likelihood with all parameters at zero.
 #'                      }
@@ -44,6 +45,7 @@
 #'           \item \strong{\code{"raw"}}: Same as \code{"estimate"}
 #'           \item \strong{\code{"report"}}: Dependent variable overview.
 #'           \item \strong{\code{"shares_LL"}}: Not implemented. Returns a vector of NA with as many elements as observations.
+#'           \item \strong{\code{"utilities"}}: List of vectors/matrices/arrays. Returns the x values.
 #'           \item \strong{\code{"validate"}}: Same as \code{"estimate"}, but it also runs a set of tests to validate the function inputs.
 #'           \item \strong{\code{"zero_LL"}}: Not implemented. Returns a vector of NA with as many elements as observations.
 #'         }
@@ -219,6 +221,14 @@ apollo_normalDensity <- function(normalDensity_settings, functionality){
     return(ans)
   } 
 
+  # ############################### #
+  #### functionality="utilities" ####
+  # ############################### #
+  
+  if(functionality %in% c("utilities")){
+    return(normalDensity_settings$xNormal)
+  }
+  
   # ################################################################# #
   #### functionality="estimate/conditionals/raw/output/components" ####
   # ################################################################# #
